import textwrap
import urllib
import time
import csv
import sys
import os

from gettext import gettext as _

import files

from core import Core
c = Core()

def get_affected_srcpkgs(bug):
    lpbugs = False
    try:
        import launchpadbugs.connector as Connector
        Bug = Connector.ConnectBug(method="Text")
        lpbugs = True
    except:
        print _("""Warning: Please install  python-launchpad-bugs
    It will add more information about the bug to your signature.""")

    try:
        affects = set(map(lambda a: a.affects.longname.lower(), 
                          Bug(int(bug)).infotable))
        affects = filter(lambda a: a.count("ubuntu"), affects)
        affects = map(lambda a: a.replace(" (ubuntu)", ""), affects)
    except:
        affects = None

    return affects    


def generate_signature(log, date):
    d = time.localtime(date)
    log = filter(lambda a: int(a[0]) > date-24*60*60, log)
    if len(log)>5:
        log = list(log)[-5:]
    text = "My 5 today: "
    html = """
<p style='color:lightslategray'>--<br />
My 5 today: """
    for line in log:
        bugnr = line[1]
        srcpkgs = ""
        affects = get_affected_srcpkgs(bugnr)
        if affects:
            srcpkgs = str(", ".join(affects))
            text += "#%s (%s), " % (bugnr, srcpkgs)
            html += "#<a href='https://launchpad.net/bugs/%s'>%s</a> (%s), " % (bugnr, bugnr, srcpkgs)
        else:
            text += "#%s, " % (bugnr)
            html += "#<a href='https://launchpad.net/bugs/%s'>%s</a>, " % (bugnr, bugnr)
    text = "\n".join(textwrap.wrap(text[:-2], 70))
    html = html[:-2]
    text += """
Do 5 a day - every day! https://wiki.ubuntu.com/5-A-Day\n"""
    html += """<br />
Do 5 a day - every day! <a href='https://wiki.ubuntu.com/5-A-Day'>https://wiki.ubuntu.com/5-A-Day</a></p>"""
    
    return (text, html)


def update(show_html, yesterday):
    url = "http://daniel.holba.ch/five-a-day-stats/people/%s.data" % c.lplogin
    try: 
        page = urllib.urlopen(url)
    except:
        print >> sys.stderr, \
            _("""No logs of your activity yet. Did you join ~5-a-day-participants already?
If you did, you might need to wait a bit until the stats are updated.""")
        sys.exit(1)

    log = [a for a in csv.reader(page.readlines())]
    files.preserve_old_signature()

    if yesterday:
        date = time.time()-24*3600
    else:
        date = time.time()
    
    (text, html) = generate_signature(log, date)
    f = open(c.signature_file, "a")
    if os.path.exists(c.old_signature_file):
        f.write(open(c.old_signature_file).read())
        f.write("\n")
    f.write(text)
    f.close()

    if show_html:
        print html

    return 0

